pub struct X509BundlesResponse {
pub crl: Vec<Bytes>,
pub bundles: HashMap<String, Bytes>,
}Expand description
The X509BundlesResponse message carries a set of global CRLs and a map of trust bundles the workload should trust.
Fields
crl: Vec<Bytes>Optional. ASN.1 DER encoded certificate revocation lists.
bundles: HashMap<String, Bytes>Required. CA certificate bundles belonging to trust domains that the workload should trust, keyed by the SPIFFE ID of the trust domain. Bundles are ASN.1 DER encoded.